--- libmpeg2/cpu_accel.c.orig
+++ libmpeg2/cpu_accel.c
@@ -29,7 +29,7 @@
 #include "attributes.h"
 #include "mpeg2_internal.h"
 
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#if defined(__i386__) || defined(__x86_64__)
 static inline uint32_t arch_accel (uint32_t accel)
 {
     if (accel & (MPEG2_ACCEL_X86_3DNOW | MPEG2_ACCEL_X86_MMXEXT))
@@ -125,9 +125,9 @@ static inline uint32_t arch_accel (uint3
 
     return accel;
 }
-#endif /* ARCH_X86 || ARCH_X86_64 */
+#endif /* __i386__ || __x86_64__ */
 
-#if defined(ACCEL_DETECT) && (defined(ARCH_PPC) || defined(ARCH_SPARC))
+#if defined(ACCEL_DETECT) && (defined(__ppc__) || defined(__sparc__))
 #include <signal.h>
 #include <setjmp.h>
 
@@ -144,9 +144,9 @@ static RETSIGTYPE sigill_handler (int si
     canjump = 0;
     siglongjmp (jmpbuf, 1);
 }
-#endif /* ACCEL_DETECT && (ARCH_PPC || ARCH_SPARC) */
+#endif /* ACCEL_DETECT && (__ppc__ || __sparc__) */
 
-#ifdef ARCH_PPC
+#ifdef __ppc__
 static uint32_t arch_accel (uint32_t accel)
 {
 #ifdef ACCEL_DETECT
@@ -181,9 +181,9 @@ static uint32_t arch_accel (uint32_t acc
 
     return accel;
 }
-#endif /* ARCH_PPC */
+#endif /* __ppc__ */
 
-#ifdef ARCH_SPARC
+#ifdef __sparc__
 static uint32_t arch_accel (uint32_t accel)
 {
     if (accel & MPEG2_ACCEL_SPARC_VIS2)
@@ -227,9 +227,9 @@ static uint32_t arch_accel (uint32_t acc
 
     return accel;
 }
-#endif /* ARCH_SPARC */
+#endif /* __sparc__ */
 
-#ifdef ARCH_ALPHA
+#ifdef __alpha__
 static inline uint32_t arch_accel (uint32_t accel)
 {
     if (accel & MPEG2_ACCEL_ALPHA_MVI)
@@ -249,11 +249,11 @@ static inline uint32_t arch_accel (uint3
 
     return accel;
 }
-#endif /* ARCH_ALPHA */
+#endif /* __alpha__ */
 
 uint32_t mpeg2_detect_accel (uint32_t accel)
 {
-#if defined (ARCH_X86) || defined (ARCH_X86_64) || defined (ARCH_PPC) || defined (ARCH_ALPHA) || defined (ARCH_SPARC)
+#if defined (__i386__) || defined (__x86_64__) || defined (__ppc__) || defined (__alpha__) || defined (__sparc__)
     accel = arch_accel (accel);
 #endif
     return accel;
--- libmpeg2/cpu_state.c.orig
+++ libmpeg2/cpu_state.c
@@ -29,21 +29,21 @@
 #include "mpeg2.h"
 #include "attributes.h"
 #include "mpeg2_internal.h"
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#if defined(__i386__) || defined(__x86_64__)
 #include "mmx.h"
 #endif
 
 void (* mpeg2_cpu_state_save) (cpu_state_t * state) = NULL;
 void (* mpeg2_cpu_state_restore) (cpu_state_t * state) = NULL;
 
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#if defined(__i386__) || defined(__x86_64__)
 static void state_restore_mmx (cpu_state_t * state)
 {
     emms ();
 }
 #endif
 
-#ifdef ARCH_PPC
+#ifdef __ppc__
 #if defined(__APPLE_CC__)	/* apple */
 #define LI(a,b) "li r" #a "," #b "\n\t"
 #define STVX0(a,b,c) "stvx v" #a ",0,r" #c "\n\t"
@@ -115,12 +115,12 @@ static void state_restore_altivec (cpu_s
 
 void mpeg2_cpu_state_init (uint32_t accel)
 {
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#if defined(__i386__) || defined(__x86_64__)
     if (accel & MPEG2_ACCEL_X86_MMX) {
 	mpeg2_cpu_state_restore = state_restore_mmx;
     }
 #endif
-#ifdef ARCH_PPC
+#ifdef __ppc__
     if (accel & MPEG2_ACCEL_PPC_ALTIVEC) {
 	mpeg2_cpu_state_save = state_save_altivec;
 	mpeg2_cpu_state_restore = state_restore_altivec;
--- libmpeg2/idct.c.orig
+++ libmpeg2/idct.c
@@ -235,7 +235,7 @@ static void mpeg2_idct_add_c (const int 
 
 void mpeg2_idct_init (uint32_t accel)
 {
-#ifdef ARCH_X86
+#ifdef __i386__
     if (accel & MPEG2_ACCEL_X86_SSE2) {
 	mpeg2_idct_copy = mpeg2_idct_copy_sse2;
 	mpeg2_idct_add = mpeg2_idct_add_sse2;
@@ -250,14 +250,14 @@ void mpeg2_idct_init (uint32_t accel)
 	mpeg2_idct_mmx_init ();
     } else
 #endif
-#ifdef ARCH_PPC
+#ifdef __ppc__
     if (accel & MPEG2_ACCEL_PPC_ALTIVEC) {
 	mpeg2_idct_copy = mpeg2_idct_copy_altivec;
 	mpeg2_idct_add = mpeg2_idct_add_altivec;
 	mpeg2_idct_altivec_init ();
     } else
 #endif
-#ifdef ARCH_ALPHA
+#ifdef __alpha__
     if (accel & MPEG2_ACCEL_ALPHA_MVI) {
 	mpeg2_idct_copy = mpeg2_idct_copy_mvi;
 	mpeg2_idct_add = mpeg2_idct_add_mvi;
--- libmpeg2/idct_alpha.c.orig
+++ libmpeg2/idct_alpha.c
@@ -24,7 +24,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_ALPHA
+#ifdef __alpha__
 
 #include <stdlib.h>
 #include <inttypes.h>
@@ -374,4 +374,4 @@ void mpeg2_idct_alpha_init (void)
     }
 }
 
-#endif /* ARCH_ALPHA */
+#endif /* __alpha__ */
--- libmpeg2/idct_altivec.c.orig
+++ libmpeg2/idct_altivec.c
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_PPC
+#ifdef __ALTIVEC__
 
 #ifdef HAVE_ALTIVEC_H
 #include <altivec.h>
--- libmpeg2/idct_mmx.c.orig
+++ libmpeg2/idct_mmx.c
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#ifdef __MMX__
 
 #include <inttypes.h>
 
--- libmpeg2/motion_comp.c.orig
+++ libmpeg2/motion_comp.c
@@ -33,7 +33,7 @@ mpeg2_mc_t mpeg2_mc;
 
 void mpeg2_mc_init (uint32_t accel)
 {
-#ifdef ARCH_X86
+#ifdef __i386__
     if (accel & MPEG2_ACCEL_X86_MMXEXT)
 	mpeg2_mc = mpeg2_mc_mmxext;
     else if (accel & MPEG2_ACCEL_X86_3DNOW)
@@ -42,22 +42,22 @@ void mpeg2_mc_init (uint32_t accel)
 	mpeg2_mc = mpeg2_mc_mmx;
     else
 #endif
-#ifdef ARCH_PPC
+#ifdef __ppc__
     if (accel & MPEG2_ACCEL_PPC_ALTIVEC)
 	mpeg2_mc = mpeg2_mc_altivec;
     else
 #endif
-#ifdef ARCH_ALPHA
+#ifdef __alpha__
     if (accel & MPEG2_ACCEL_ALPHA)
 	mpeg2_mc = mpeg2_mc_alpha;
     else
 #endif
-#ifdef ARCH_SPARC
+#ifdef __sparc__
     if (accel & MPEG2_ACCEL_SPARC_VIS)
 	mpeg2_mc = mpeg2_mc_vis;
     else
 #endif
-#ifdef ARCH_ARM
+#ifdef __arm__
     if (accel & MPEG2_ACCEL_ARM) {
 	mpeg2_mc = mpeg2_mc_arm;
     } else
--- libmpeg2/motion_comp_alpha.c.orig
+++ libmpeg2/motion_comp_alpha.c
@@ -22,7 +22,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_ALPHA
+#ifdef __alpha__
 
 #include <inttypes.h>
 
--- libmpeg2/motion_comp_altivec.c.orig
+++ libmpeg2/motion_comp_altivec.c
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_PPC
+#ifdef __ALTIVEC__
 
 #ifdef HAVE_ALTIVEC_H
 #include <altivec.h>
--- libmpeg2/motion_comp_arm.c.orig
+++ libmpeg2/motion_comp_arm.c
@@ -22,7 +22,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_ARM
+#ifdef __arm__
 
 #include <inttypes.h>
 
--- libmpeg2/motion_comp_mmx.c.orig
+++ libmpeg2/motion_comp_mmx.c
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#if defined(ARCH_X86) || defined(ARCH_X86_64)
+#ifdef __MMX__
 
 #include <inttypes.h>
 
--- libmpeg2/motion_comp_vis.c.orig
+++ libmpeg2/motion_comp_vis.c
@@ -22,7 +22,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_SPARC
+#ifdef __sparc__
 
 #include <inttypes.h>
 
@@ -2058,4 +2058,4 @@ static void MC_avg_xy_8_vis (uint8_t * d
 
 MPEG2_MC_EXTERN(vis);
 
-#endif  /* !(ARCH_SPARC) */
+#endif  /* !(__sparc__) */
--- libmpeg2/mpeg2_internal.h.orig
+++ libmpeg2/mpeg2_internal.h
@@ -226,7 +226,7 @@ struct mpeg2dec_s {
 };
 
 typedef struct {
-#ifdef ARCH_PPC
+#ifdef __ppc__
     uint8_t regv[12*16];
 #endif
     int dummy;
--- libvo/video_out_pgm.c.orig
+++ libvo/video_out_pgm.c
@@ -285,7 +285,7 @@ static void md5_writer (pgm_instance_t *
     }
 
     while (size >= 64) {
-#ifndef ARCH_X86
+#ifndef __i386__
 	memcpy (instance->md5_block, ptr, 64);
 	little_endian (instance->md5_block, 16);
 	md5_transform (instance->md5_hash, instance->md5_block);
